@@ -1,6 +1,6 @@
-use 5.008001;
+use strict; use warnings;
 package YAML::Old;
-our $VERSION = '0.99';
+our $VERSION = '1.07';
 
 use YAML::Old::Mo;
 
